@@ -40,7 +40,7 @@ def test_abstract():
 
 def test_affiliation():
     aff = namedtuple('Affiliation', 'id name city country')
-    expected = [aff(id='60027950', name='Carnegie Mellon University',
+    expected = [aff(id=60027950, name='Carnegie Mellon University',
                     city='Pittsburgh', country='United States')]
     assert_equal(ab1.affiliation, expected)
     assert_equal(ab3.affiliation, None)
@@ -65,10 +65,10 @@ def test_authorgroup():
     fields = 'affiliation_id dptid organization city postalcode '\
              'addresspart country auid indexed_name surname given_name'
     auth = namedtuple('Author', fields)
-    expected = [auth(affiliation_id='60027950', dptid='110785688',
+    expected = [auth(affiliation_id=60027950, dptid=110785688,
         organization='Department of Chemical Engineering, Carnegie Mellon University',
         city='Pittsburgh', postalcode='15213', addresspart='5000 Forbes Avenue',
-        country='United States', auid='7004212771',
+        country='United States', auid=7004212771,
         indexed_name='Kitchin J.', surname='Kitchin', given_name='John R.')]
     assert_equal(ab1.authorgroup, expected)
     assert_equal(ab8.authorgroup, None)
@@ -77,9 +77,9 @@ def test_authorgroup():
 def test_authors():
     fields = 'auid indexed_name surname given_name affiliation_id'
     auth = namedtuple('Author', fields)
-    expected = [auth(auid='7004212771', indexed_name='Kitchin J.R.',
+    expected = [auth(auid=7004212771, indexed_name='Kitchin J.R.',
                 surname='Kitchin', given_name='John R.',
-                affiliation_id=['60027950'])]
+                affiliation_id='60027950')]
     assert_equal(ab1.authors, expected)
     assert_equal(ab8.authors, None)
 
@@ -110,7 +110,7 @@ def test_chemials():
 
 
 def test_confcode():
-    assert_equal(ab2.confcode, '44367')
+    assert_equal(ab2.confcode, 44367)
     assert_equal(ab8.confcode, None)
 
 
@@ -162,7 +162,7 @@ def test_correspondence():
     expected2 = corr(surname='Boukas', initials='E.K.',
         organization='Ecole Polytechnique de Montreal', country='Canada',
         city_group='Montreal')
-    assert_equal(ab2.correspondence, expected2)
+    assert_equal(ab2.correspondence[0], expected2)
     assert_equal(ab3.correspondence, None)
     assert_equal(ab8.correspondence, None)
 
@@ -264,7 +264,7 @@ def test_get_html():
         'https://www.scopus.com/authid/detail.url?origin=AuthorProfile&'\
         'authorId=16430389100">Gwen Ortmeyer</a> and <a href="https://'\
         'www.scopus.com/authid/detail.url?origin=AuthorProfile&authorId='\
-        '55613241349">N. Craig Smith</a>, <a href="https://www.scopus.com/'\
+        '55613241342">N. Craig Smith</a>, <a href="https://www.scopus.com/'\
         'inward/record.uri?partnerID=HzOxMe3b&scp=0001270077&origin=inward">'\
         'Fairness in consumer pricing</a>, <a href="https://www.scopus.com/'\
         'source/sourceInfo.url?sourceId=130073">Journal of Consumer Policy'\
@@ -286,7 +286,7 @@ def test_issn():
 
 
 def test_identifier():
-    assert_equal(ab1.identifier, '84930616647')
+    assert_equal(ab1.identifier, 84930616647)
     assert_equal(ab8.identifier, None)
 
 
@@ -314,9 +314,9 @@ def test_language():
 
 
 def test_openaccess():
-    assert_equal(ab5.openaccess, "2")
-    assert_equal(ab6.openaccess, "1")
-    assert_equal(ab7.openaccess, "0")
+    assert_equal(ab5.openaccess, 2)
+    assert_equal(ab6.openaccess, 1)
+    assert_equal(ab7.openaccess, 0)
     assert_equal(ab8.openaccess, None)
 
 
@@ -354,13 +354,13 @@ def test_publisheraddress():
 
 
 def test_pubmed_id():
-    assert_equal(ab6.pubmed_id, '29284752')
+    assert_equal(ab6.pubmed_id, 29284752)
     assert_equal(ab7.pubmed_id, None)
 
 
 def test_refcount():
-    assert_equal(ab4.refcount, '18')
-    assert_equal(ab8.refcount, '48')
+    assert_equal(ab4.refcount, 18)
+    assert_equal(ab8.refcount, 48)
 
 
 def test_references_full():
@@ -427,7 +427,7 @@ def test_sequencebank():
 
 
 def test_source_id():
-    assert_equal(ab1.source_id, '19700188320')
+    assert_equal(ab1.source_id, 19700188320)
     assert_equal(ab8.source_id, None)
 
 
@@ -449,8 +449,8 @@ def test_startingPage():
 
 def test_subject_areas():
     area = namedtuple('Area', 'area abbreviation code')
-    expected = [area(area='Catalysis', abbreviation='CENG', code='1503'),
-                area(area='Chemistry (all)', abbreviation='CHEM', code='1600')]
+    expected = [area(area='Catalysis', abbreviation='CENG', code=1503),
+                area(area='Chemistry (all)', abbreviation='CHEM', code=1600)]
     assert_equal(ab1.subject_areas, expected)
     assert_equal(ab8.subject_areas, None)
 
