@@ -1,11 +1,8 @@
-import os
-
 import requests
 
-from pybliometrics.scopus import exception
-from pybliometrics.scopus.utils import CONFIG_FILE, DEFAULT_PATHS, config
-from pybliometrics.scopus.utils.create_config import create_config
 from pybliometrics import version_info
+from pybliometrics.scopus import exception
+from pybliometrics.scopus.utils.startup import config
 
 # Define user agent string for HTTP requests
 user_agent = 'pybliometrics-v' + '.'.join([str(e) for e in version_info[:3]])
@@ -17,20 +14,23 @@ errors = {400: exception.Scopus400Error, 401: exception.Scopus401Error,
           502: exception.Scopus502Error}
 
 
-def get_content(url, params={}, *args, **kwds):
+def get_content(url, api, params={}, **kwds):
     """Helper function to download a file and return its content.
 
     Parameters
     ----------
-    url : string
+    url : str
         The URL to be parsed.
 
+    api : str
+        The Scopus API to be accessed.
+
     params : dict (optional)
         Dictionary containing query parameters.  For required keys
         and accepted values see e.g.
         https://api.elsevier.com/documentation/AuthorRetrievalAPI.wadl
 
-    *args, **kwds : key-value parings, optional
+    **kwds : key-value parings, optional
         Keywords passed on to as query parameters.  Must contain fields
         and values specified in the respective API specification.
 
@@ -48,12 +48,14 @@ def get_content(url, params={}, *args, **kwds):
         The content of the file, which needs to be serialized.
     """
     from random import shuffle
+    from time import sleep, time
 
     from simplejson import JSONDecodeError
 
+    from pybliometrics.scopus.utils.startup import _throttling_params, KEYS
+
     # Set header, params and proxy
-    keys = config.get('Authentication', 'APIKey').split(",")
-    header = {'X-ELS-APIKey': keys[0].strip(),
+    header = {'X-ELS-APIKey': KEYS[0],
               'Accept': 'application/json',
               'User-Agent': user_agent}
     if config.has_option('Authentication', 'InstToken'):
@@ -62,18 +64,25 @@ def get_content(url, params={}, *args, **kwds):
     params.update(**kwds)
     proxies = dict(config._sections.get("Proxy", {}))
 
+    # Eventually wait bc of throttling
+    if len(_throttling_params[api]) == _throttling_params[api].maxlen:
+        try:
+            sleep(1 - (time() - _throttling_params[api][0]))
+        except (IndexError, ValueError):
+            pass
+
     # Perform request, eventually replacing the current key
     resp = requests.get(url, headers=header, proxies=proxies, params=params)
     while resp.status_code == 429:
         try:
-            keys.pop(0)  # Remove current key
-            shuffle(keys)
-            header['X-ELS-APIKey'] = keys[0].strip()
+            KEYS.pop(0)  # Remove current key
+            shuffle(KEYS)
+            header['X-ELS-APIKey'] = KEYS[0].strip()
             resp = requests.get(url, headers=header, proxies=proxies,
                                 params=params)
-            config['Authentication']['APIKey'] = ",".join(list(keys))
         except IndexError:  # All keys depleted
             break
+    _throttling_params[api].append(time())
 
     # Eventually raise error, if possible with supplied error message
     try:
@@ -110,18 +119,14 @@ def detect_id_type(sid):
     work with both types, consider specifying the ID type manually.
     """
     sid = str(sid)
-    try:
-        isnumeric = sid.isnumeric()
-    except AttributeError:  # Python2
-        isnumeric = unicode(sid, 'utf-8').isnumeric()
-    if not isnumeric:
+    if not sid.isnumeric():
         if sid.startswith('1-s2.0-') or sid.startswith('2-s2.0-'):
             id_type = 'eid'
         elif '/' in sid or "." in sid:
             id_type = 'doi'
         elif 16 <= len(sid) <= 17:
             id_type = 'pii'
-    elif isnumeric:
+    else:
         if len(sid) < 10:
             id_type = 'pubmed_id'
         else:
@@ -137,26 +142,23 @@ def get_folder(api, view):
     eventually create the folder.
     """
     from configparser import NoOptionError
+    from pathlib import Path
+
+    from pybliometrics.scopus.utils import CONFIG_FILE, DEFAULT_PATHS
+    from pybliometrics.scopus.utils.create_config import create_config
+
     if not config.has_section('Directories'):
         create_config()
     try:
-        folder = config.get('Directories', api)
+        parent = Path(config.get('Directories', api))
     except NoOptionError:
-        folder = DEFAULT_PATHS[api]
-        config.set('Directories', api, folder)
-        with open(CONFIG_FILE, 'w') as f:
-            config.write(f)
-    folder = os.path.join(folder, view or '')
-    if not os.path.exists(folder):
-        os.makedirs(folder)
+        parent = DEFAULT_PATHS[api]
+        config.set('Directories', api, str(parent))
+        with open(CONFIG_FILE, 'w') as ouf:
+            config.write(ouf)
+    try:
+        folder = parent/view
+    except TypeError:
+        folder = parent
+    folder.mkdir(parents=True, exist_ok=True)
     return folder
-
-
-def print_progress(iteration, total, length=50):
-    """Print terminal progress bar."""
-    share = iteration / float(total)
-    filled_len = int(length * iteration // total)
-    bar = '█' * filled_len + '-' * (length - filled_len)
-    print(f'\rProgress: |{bar}| {share:.2%} Complete', end='\r')
-    if iteration == total:
-        print()
