@@ -4,7 +4,7 @@ from warnings import warn
 
 def chained_get(container, path, default=None):
     """Helper function to perform a series of .get() methods on a dictionary
-    and return a default object type in the end.
+    or return the `default`.
 
     Parameters
     ----------
@@ -18,12 +18,13 @@ def chained_get(container, path, default=None):
         The object type that should be returned if the search yields
         no result.
     """
-    for key in path:
-        try:
-            container = container[key]
-        except (AttributeError, KeyError, TypeError):
-            return default
-    return container
+    from functools import reduce
+
+    # Obtain value via reduce
+    try:
+        return reduce(lambda c, k: c.get(k, default), path, container)
+    except (AttributeError, TypeError):
+        return default
 
 
 def check_integrity(tuples, fields, action):
@@ -42,13 +43,6 @@ def check_integrity(tuples, fields, action):
             warn(msg)
 
 
-def check_integrity_params(action, allowed=("warn", "raise")):
-    """Verify that the passed integrity action parameters valid ones."""
-    if action not in allowed:
-        msg = 'integrity_action parameter must be one of ' + ', '.join(allowed)
-        raise ValueError(msg)
-
-
 def check_field_consistency(needles, haystack):
     """Raise ValueError if elements of a list are not present in a string."""
     wrong = set(needles) - set(haystack.split())
@@ -58,10 +52,13 @@ def check_field_consistency(needles, haystack):
         raise ValueError(msg)
 
 
-def get_id(s):
+def get_id(s, integer=True):
     """Helper function to return the Scopus ID at a fixed position."""
     path = ['coredata', 'dc:identifier']
-    return chained_get(s, path, "").split(':')[-1] or None
+    try:
+        return int(chained_get(s, path, "").split(':')[-1])
+    except ValueError:
+        return None
 
 
 def get_link(dct, idx, path=['coredata', 'link']):
@@ -82,6 +79,14 @@ def listify(element):
         return [element]
 
 
+def make_int_if_possible(val):
+    """Attempt a conversion to int type."""
+    try:
+        return int(val)
+    except TypeError:
+        return val
+
+
 def make_search_summary(self, keyword, results, joiner="\n    "):
     """Create string for str dunder of search classes."""
     date = self.get_cache_file_mdate().split()[0]
@@ -91,7 +96,7 @@ def make_search_summary(self, keyword, results, joiner="\n    "):
     else:
         appendix = ""
         verb = "has"
-    s = f"Search '{self.query}' yielded {self._n:,} "\
+    s = f"Search '{self._query}' yielded {self._n:,} "\
         f"{keyword}{appendix} as of {date}"
     if results:
         s += ":" + joiner + joiner.join(results)
@@ -112,7 +117,11 @@ def parse_affiliation(affs):
             continue
         doc = item.get('ip-doc', {}) or {}
         address = doc.get('address', {}) or {}
-        new = aff(id=item.get('@affiliation-id'), parent=item.get('@parent'),
+        try:
+            parent = int(item['@parent'])
+        except KeyError:
+            parent = None
+        new = aff(id=int(item['@affiliation-id']), parent=parent,
             type=doc.get('@type'), relationship=doc.get('@relationship'),
             afdispname=doc.get('@afdispname'),
             preferred_name=doc.get('preferred-name', {}).get('$'),
@@ -129,6 +138,6 @@ def parse_date_created(dct):
     """Helper function to parse date-created from profile."""
     date = dct['date-created']
     if date:
-        return (int(date['@year']), int(date['@month']), int(date['@day']))
+        return int(date['@year']), int(date['@month']), int(date['@day'])
     else:
-        return (None, None, None)
+        return None, None, None
